agentle.mcp.resources.resource\_content
=======================================

.. automodule:: agentle.mcp.resources.resource_content

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      Base64Str
      BaseModel
      ResourceContent
   